@@ -161,6 +161,8 @@ typedef struct {
     struct timespec ts;
 } ProcessedSignalData;
 
+static const gchar *key_remote_changes = "ag_remote_changes";
+
 static void ag_manager_initable_iface_init(gpointer g_iface,
                                            gpointer iface_data);
 
@@ -185,6 +187,7 @@ on_dbus_store_done (GObject *object, GAsyncResult *res,
     GVariant *result;
     GError *error_int = NULL;
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     result = g_dbus_connection_call_finish (conn, res, &error_int);
     if (G_UNLIKELY (error_int))
     {
@@ -199,11 +202,27 @@ on_dbus_store_done (GObject *object, GAsyncResult *res,
     }
     else
     {
+        GObject *source =
+            g_async_result_get_source_object ((GAsyncResult *)async_result);
+        AgAccount *account = AG_ACCOUNT (source);
+        /* If this was a new account, we must update the local data
+         * structure */
+        if (account->id == 0 &&
+            g_variant_n_children (result) >= 1)
+        {
+            AgAccountChanges *changes;
+
+            g_variant_get_child (result, 0, "u", &account->id);
+            changes = g_object_get_data ((GObject *)async_result,
+                                         key_remote_changes);
+            _ag_account_done_changes (account, changes);
+        }
         g_variant_unref (result);
     }
 
     g_simple_async_result_complete_in_idle (async_result);
     g_object_unref (async_result);
+G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 static void
@@ -216,17 +235,22 @@ ag_manager_store_dbus_async (AgManager *manager, AgAccount *account,
     GVariant *dbus_changes;
 
     if (G_UNLIKELY (!priv->use_dbus)) {
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         g_simple_async_result_set_error (async_result,
                                          AG_ACCOUNTS_ERROR,
                                          AG_ACCOUNTS_ERROR_READONLY,
                                          "DB read-only and D-Bus disabled");
         g_simple_async_result_complete_in_idle (async_result);
+G_GNUC_END_IGNORE_DEPRECATIONS
         g_object_unref (async_result);
         return;
     }
 
     changes = _ag_account_steal_changes (account);
     dbus_changes = _ag_account_build_dbus_changes (account, changes, NULL);
+    g_object_set_data_full ((GObject *)async_result,
+                            key_remote_changes, changes,
+                            (GDestroyNotify) _ag_account_changes_free);
 
     g_dbus_connection_call (priv->dbus_conn,
                             AG_MANAGER_SERVICE_NAME,
@@ -240,8 +264,6 @@ ag_manager_store_dbus_async (AgManager *manager, AgAccount *account,
                             cancellable,
                             (GAsyncReadyCallback)on_dbus_store_done,
                             async_result);
-
-    _ag_account_changes_free (changes);
 }
 
 static gboolean
@@ -251,6 +273,7 @@ ag_manager_store_dbus_sync (AgManager *manager, AgAccount *account,
     AgManagerPrivate *priv = manager->priv;
     AgAccountChanges *changes;
     GVariant *dbus_changes;
+    GVariant *result;
     GError *error_int = NULL;
 
     if (G_UNLIKELY (!priv->use_dbus)) {
@@ -264,19 +287,18 @@ ag_manager_store_dbus_sync (AgManager *manager, AgAccount *account,
     changes = _ag_account_steal_changes (account);
     dbus_changes = _ag_account_build_dbus_changes (account, changes, NULL);
 
-    g_dbus_connection_call_sync (priv->dbus_conn,
-                            AG_MANAGER_SERVICE_NAME,
-                            AG_MANAGER_OBJECT_PATH,
-                            AG_MANAGER_INTERFACE,
-                            "store",
-                            dbus_changes,
-                            NULL,
-                            G_DBUS_CALL_FLAGS_NONE,
-                            -1,
-                            NULL,
-                            &error_int);
-
-    _ag_account_changes_free (changes);
+    result =
+        g_dbus_connection_call_sync (priv->dbus_conn,
+                                     AG_MANAGER_SERVICE_NAME,
+                                     AG_MANAGER_OBJECT_PATH,
+                                     AG_MANAGER_INTERFACE,
+                                     "store",
+                                     dbus_changes,
+                                     NULL,
+                                     G_DBUS_CALL_FLAGS_NONE,
+                                     -1,
+                                     NULL,
+                                     &error_int);
 
     if (G_UNLIKELY (error_int))
     {
@@ -286,9 +308,18 @@ ag_manager_store_dbus_sync (AgManager *manager, AgAccount *account,
                              AG_ACCOUNTS_ERROR_READONLY,
                              error_int->message);
         g_error_free (error_int);
+        _ag_account_changes_free (changes);
         return FALSE;
     }
 
+    if (account->id == 0 &&
+        g_variant_n_children (result) >= 1)
+    {
+        g_variant_get_child (result, 0, "u", &account->id);
+        _ag_account_done_changes (account, changes);
+    }
+
+    _ag_account_changes_free (changes);
     return TRUE;
 }
 
@@ -353,7 +384,7 @@ list_data_files (AgManager *manager,
     GList *file_list;
     const gchar * const *dirs;
     const gchar *env_dirname, *datadir;
-    gchar *dirname;
+    gchar *dirname, *desktop_override = NULL;
 
     loaded_files = g_hash_table_new_full (g_str_hash, g_str_equal,
                                           g_free, NULL);
@@ -376,9 +407,23 @@ list_data_files (AgManager *manager,
         g_free (dirname);
     }
 
+    /* Check what desktop is this running on */
+    env_dirname = g_getenv ("XDG_CURRENT_DESKTOP");
+    if (env_dirname)
+        desktop_override = g_ascii_strdown (env_dirname, -1);
+
     dirs = g_get_system_data_dirs ();
     for (datadir = *dirs; datadir != NULL; dirs++, datadir = *dirs)
     {
+        /* Check first if desktop override files exist and if yes, load them first */
+        if (desktop_override)
+        {
+            dirname = g_build_filename (datadir, subdir, desktop_override, NULL);
+            add_data_files_from_dir (manager, dirname, loaded_files, suffix,
+                                     load_file_func);
+            g_free (dirname);
+        }
+
         dirname = g_build_filename (datadir, subdir, NULL);
         add_data_files_from_dir (manager, dirname, loaded_files, suffix,
                                  load_file_func);
@@ -388,6 +433,7 @@ list_data_files (AgManager *manager,
 finish:
     file_list = g_hash_table_get_values (loaded_files);
     g_hash_table_unref (loaded_files);
+    g_free (desktop_override);
 
     return file_list;
 }
@@ -490,7 +536,7 @@ static void
 set_error_from_db (AgManager *manager)
 {
     AgManagerPrivate *priv = manager->priv;
-    AgError code;
+    AgAccountsError code;
     GError *error;
 
     switch (sqlite3_errcode (priv->db))
@@ -668,16 +714,18 @@ dbus_filter_callback (G_GNUC_UNUSED GDBusConnection *dbus_conn,
     if (!object_path_is_interesting (object_path, priv->object_paths))
         return;
 
-    memset (&ts, 0, sizeof (struct timespec));
+    guint32 sec, nsec;
     g_variant_get (msg,
                    "(uuubb&s@*)",
-                   &ts.tv_sec,
-                   &ts.tv_nsec,
+                   &sec,
+                   &nsec,
                    &account_id,
                    &created,
                    &deleted,
                    &provider_name,
                    &v_services);
+    ts.tv_sec = sec;
+    ts.tv_nsec = nsec;
 
     DEBUG_INFO ("path = %s, time = %lu-%lu (%p)",
                 object_path, ts.tv_sec, ts.tv_nsec,
@@ -1077,7 +1125,9 @@ exec_transaction_idle (StoreCbData *sd)
 finish:
     if (error != NULL)
     {
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         g_simple_async_result_take_error (sd->async_result, error);
+G_GNUC_END_IGNORE_DEPRECATIONS
     }
 
     _ag_account_store_completed (account, sd->changes);
@@ -2382,7 +2432,9 @@ _ag_manager_exec_transaction (AgManager *manager, const gchar *sql,
 finish:
     if (error != NULL)
     {
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         g_simple_async_result_take_error (async_result, error);
+G_GNUC_END_IGNORE_DEPRECATIONS
     }
 
     _ag_account_store_completed (account, changes);
@@ -2443,9 +2495,11 @@ ag_manager_store_local_async (AgManager *manager, AgAccount *account,
     sql = _ag_account_get_store_sql (account, &error);
     if (G_UNLIKELY (error))
     {
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         g_simple_async_result_take_error (async_result,
                                           error);
         g_simple_async_result_complete_in_idle (async_result);
+G_GNUC_END_IGNORE_DEPRECATIONS
         g_object_unref (async_result);
         return;
     }
